@@ -16,7 +16,7 @@ namespace citygml {
         AppearanceElementParser(CityGMLDocumentParser& documentParser, CityGMLFactory& factory, std::shared_ptr<CityGMLLogger> logger);
 
         // ElementParser interface
-        virtual std::string elementParserName() const;
+        virtual std::string elementParserName() const override;
         virtual bool handlesElement(const NodeType::XMLNode &node) const override;
 
     protected:
@@ -30,7 +30,7 @@ namespace citygml {
         virtual Object* getObject() override;
 
     private:
-        std::vector<std::shared_ptr<Appearance>> m_surfaceDataList;
+        std::vector<std::shared_ptr<Appearance> > m_surfaceDataList;
         std::shared_ptr<Object> m_appearanceObj;
         std::string m_theme;
     };
