@@ -8,12 +8,12 @@
 #include "parser/parserutils.hpp"
 #include "parser/skipelementparser.h"
 
-#include "citygml/cityobject.h"
-#include "citygml/citygmlfactory.h"
-#include "citygml/citygmllogger.h"
-#include "citygml/texture.h"
-#include "citygml/texturetargetdefinition.h"
-#include "citygml/texturecoordinates.h"
+#include <citygml/cityobject.h>
+#include <citygml/citygmlfactory.h>
+#include <citygml/citygmllogger.h>
+#include <citygml/texture.h>
+#include <citygml/texturetargetdefinition.h>
+#include <citygml/texturecoordinates.h>
 
 #include <stdexcept>
 
